#
# spec file for package alevt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           alevt
Version:        1.8.2
Release:        1.1
Summary:        Teletext and Videotext Decoder for the BTTV Driver
License:        GPL-2.0-or-later
Group:          Hardware/TV
URL:            https://gitlab.com/alevt/alevt
Source0:        %{URL}/-/archive/v%{version}/alevt-v%{version}.tar.bz2
Source1:        alevt.desktop
Patch0:         alevt-fix-implicit.patch
# https://gitlab.com/alevt/alevt/-/issues/2
Patch1:         alevt-gcc15.patch
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(zvbi-0.2)

%description
AleVT is a teletext and videotext decoder and browser for the BTTV
driver (/dev/vbi) and the X Window System.  It features multiple
windows, a page cache, regexp searching, a built-in manual, and more.
There is also a program to get the time from teletext.

%prep
%autosetup -p1 -n alevt-v%{version}
# Enable ZVBI
sed -i "s|#DEFS+=-DUSE_LIBZVBI|DEFS+=-DUSE_LIBZVBI|" Makefile

%build
%make_build OPT="%{optflags}"

%install
%make_install PREFIX="%{_prefix}"
%suse_update_desktop_file -i alevt

%files
%license COPYRIGHT
%doc CHANGELOG README.md
%{_bindir}/alevt
%{_bindir}/alevt-cap
%{_bindir}/alevt-date
%{_datadir}/pixmaps/mini-alevt.xpm
%{_datadir}/applications/*.desktop
%{_mandir}/man1/alevt*
%{_datadir}/pixmaps/*.xpm

%changelog
* Wed Jun 18 2025 pgajdos@suse.com
- version update to 1.8.2
  * Avoid implicit function declarations in lang.c
  * remove output of serviceid et. al from alevt-date and alevt-cap
  * Fix install command in make target 'rpm-install'
  * Add simple desktop entry file
  * Fix reading of strings from DVB tables according to DVB-SI Annex A
  * Merge branch 'dvb-si-fixes' into 'master'
  * Let alevt-date display the time in the same fashion as date from coreutils
  * Adjust the command to set the RTC on Linux, it is hwclock from util-linux
  * Add a note on dvbv5-zap from DVBv5 Tools
  * Fix first line of icon48x48.xpm, it should not be a black line
- added patches
  https://gitlab.com/alevt/alevt/-/issues/2
  + alevt-gcc15.patch
* Tue May  7 2024 Marcus Meissner <meissner@suse.com>
- alevt-fix-implicit.patch: fixed implicit definitions.
* Mon Aug 23 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.8.1
  * Some SI fixes
  * Use pkg-config to find libraries, obsoletes use-pkgconfig.patch
* Mon Apr 19 2021 Martin Pluskal <mpluskal@suse.com>
- Fix previous changelog entry
* Sat Apr 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.8.0
  * DVB-T support
  * Increase program table size from 16 to 128
  * Fix crash if no DVB service has Teletext
  * Detect HEVC services for all regions (this fixes HEVC in Germany)
  * Fix 100%% cpu use when there is no vbi device
  * Add zvbi support
  * Add support for iso8859-7 (greek)
  * Add support for KOI8-R encoding
  * Support libpng-1.6
- Update to 1.6.3
  * compilation fix for libpng-1.5, this obsoletes alevt-libpng15.patch
- Dropped obsoleted alevt-1.6.0-dvb-demux.patch,
  alevt-happy-abuild.diff and alevt-overflow2.diff
  alevt-libpng15.patch
- Modernized and fixed SPEC file
  * Added working upstream URL
- Add use-pkgconfig.patch
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Fri Feb  9 2018 crrodriguez@opensuse.org
- BuildRequire pkgconfig(x11) not xorg-x11-devel
* Fri Jan  6 2012 pgajdos@suse.com
- build also with libpng15
  * libpng15.patch
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Wed Nov 25 2009 meissner@suse.de
- fixed fuzzy patches
* Wed Jan 30 2008 jw@suse.de
- updated to 1.6.2
  - adapt to current v4l2 api
  - some minor fixes collected during the past years
- upstreamed patches removed.
* Thu Jul  5 2007 coolo@suse.de
- put desktop file and icon into the package
* Tue Sep  5 2006 jw@suse.de
- fixed #203118, making -Wold-style-definition happy.
* Fri Jul 28 2006 jw@suse.de
- made xorg-safe.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul  7 2005 jw@suse.de
- revamped gcc4.diff into happy-abuild.diff
  Avoid imlicit declarations and add RPM_OPT_FLAGS where needed.
* Mon Jul  4 2005 jw@suse.de
- added alevt-gcc4.diff, comparison is always true suppression.
* Tue Apr 19 2005 jw@suse.de
- changes by tsaupe@suse.de documented in usage and man.
* Thu Apr 14 2005 jw@suse.de
- added alevt-overflow.diff by tsaupe@suse.de
* Sun Jan 23 2005 meissner@suse.de
- use RPM_OPT_FLAGS, fixed compile error with gcc4.
* Fri Nov 19 2004 ro@suse.de
- include icon in filelist
* Tue Nov  9 2004 jw@suse.de
- added http://www.baycom.org/~tom/alevt-dvb-demux.patch
  suggested by tsaupe@suse.de
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Mon Oct 13 2003 jw@suse.de
- make shall not sync (#32147)
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Tue May 27 2003 coolo@suse.de
- use BuildRoot
* Mon May 19 2003 wengel@suse.de
- update -> 1.6.1 (fixed bug in ui.c and more)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Jun  5 2002 uli@suse.de
- update -> 1.6.0 (png export, v4l2 interface & more)
* Wed Apr 24 2002 uli@suse.de
- fixed for lib64
* Wed Feb  7 2001 uli@suse.de
- fixed for glibc 2.2.1
* Sat Dec  9 2000 nashif@suse.de
- sorted group
* Fri Jun  2 2000 kukuk@suse.de
- Use doc macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jul 14 1999 uli@suse.de
- New version 1.4.9
* Wed Jul 14 1999 uli@suse.de
- Spec file created from alevt-1.4.9.tar.gz by autospec
